Learn R Programming

spaa (version 0.1.2)

niche.overlap.boot.pair: Niche overlap boostrap utility function

Description

Compute the bootstrap value between two vectors. This is a internal function called by niche.overlap.boot, users are encouraged to use the latter function.

Usage

niche.overlap.boot.pair(vectorA, vectorB, method = c("levins", "schoener", "petraitis", "pianka", "czech", "morisita"), times = 999, quant = c(0.025, 0.975))

Arguments

vectorA
A numerical vector including species A's abundance or value of importance.
vectorB
A numerical vector including species B's abundance or value of importance.
method
Niche overlap indeces to be applied.
times
Number of bootstraps
quant
Confidence interval of the bootstrap results.

Value

  • This function will return a vector including the following elements: "Observed","Boot mean","Boot std","Boot CI1", "Boot CI2", "times"

Details

To do.

References

Zhang Jin-tun,(2004 ) Quantitative Ecology, Science Press, Beijing

See Also

niche.overlap.boot

Examples

Run this code
### niche.overlap.boot.pair() example
data(datasample)
niche.overlap.boot.pair(datasample[,1],datasample[,2], method = "levins")

Run the code above in your browser using DataLab