niche.overlap: Niche overlap between each pair of species
Description
Compute niche overlap between each pair of species.Usage
niche.overlap(mat, method = c("levins", "schoener", "petraitis", "pianka", "czech", "morisita"))Arguments
mat
A community data matrix with each column for each species, and each row for each plot.
method
Index of niche overlap to be specified.
Value
- A distance matrix contains niche overlap index between each pair of species.
References
Zhang Jin-tun,(2004 ) Quantitative Ecology, Science Press, Beijing
Nicholas J. Gotelli. 2000. Null model analysis of species co-occurrence patterns. Ecology 81:2606-2621. http://esapubs.org/archive/ecol/E081/022/EcoSimExamples
Run this code### niche.overlap.boot() example
data(datasample)
niche.overlap(datasample, method = "levins")
Run the code above in your browser using DataLab